import ms from "ms";
import { Decision, VIDEO_DISC_EXTENSIONS, } from "../constants.js";
import { getRuntimeConfig } from "../runtimeConfig.js";
import { wait } from "../utils.js";
import Deluge from "./Deluge.js";
import QBittorrent from "./QBittorrent.js";
import RTorrent from "./RTorrent.js";
import Transmission from "./Transmission.js";
import { hasExt } from "../utils.js";
let activeClient = null;
function instantiateDownloadClient() {
    const { rtorrentRpcUrl, qbittorrentUrl, transmissionRpcUrl, delugeRpcUrl } = getRuntimeConfig();
    if (rtorrentRpcUrl) {
        activeClient = new RTorrent();
    }
    else if (qbittorrentUrl) {
        activeClient = new QBittorrent();
    }
    else if (transmissionRpcUrl) {
        activeClient = new Transmission();
    }
    else if (delugeRpcUrl) {
        activeClient = new Deluge();
    }
}
export function getClient() {
    if (!activeClient) {
        instantiateDownloadClient();
    }
    return activeClient;
}
export async function waitForTorrentToComplete(infoHash, options = { retries: 6 }) {
    for (let i = 0; i <= options.retries; i++) {
        if ((await getClient().isTorrentComplete(infoHash)).orElse(false)) {
            return true;
        }
        if (i < options.retries) {
            await wait(ms("1 second") * 2 ** i);
        }
    }
    return false;
}
export function shouldRecheck(searchee, decision) {
    if (decision === Decision.MATCH_PARTIAL)
        return true;
    if (hasExt(searchee.files, VIDEO_DISC_EXTENSIONS))
        return true;
    return false; // Skip for MATCH | MATCH_SIZE_ONLY
}
//# sourceMappingURL=TorrentClient.js.map